pyrlp
=====

[![Build Status](https://travis-ci.org/ethereum/pyrlp.svg?branch=develop)](https://travis-ci.org/ethereum/pyrlp)
[![Coverage Status](https://coveralls.io/repos/ethereum/pyrlp/badge.svg)](https://coveralls.io/r/ethereum/pyrlp)
[![PyPI version](https://badge.fury.io/py/rlp.svg)](http://badge.fury.io/py/rlp)

A Python implementation of Recursive Length Prefix encoding (RLP). You can find
the specification of the standard in the
[Ethereum wiki](https://github.com/ethereum/wiki/wiki/RLP) and the
documentation of this package on
[readthedocs](http://pyrlp.readthedocs.org/en/latest/).
